@@ -43,18 +43,20 @@ where
 mod facet_map {
     use crate::{Operator, TickValue, Tickable};
     use std::collections::HashMap;
+    use std::hash::Hash;
 
     /// [`FacetMap`] combinator.
     #[derive(Debug, Clone)]
-    pub struct FacetMap<I, P>(HashMap<String, P>, core::marker::PhantomData<fn() -> I>);
+    pub struct FacetMap<I, Q, P>(HashMap<Q, P>, core::marker::PhantomData<fn() -> I>);
 
-    impl<I, P> Operator<I> for FacetMap<I, P>
+    impl<I, Q, P> Operator<I> for FacetMap<I, Q, P>
     where
         I: Tickable + Clone,
+        Q: Eq + Hash + Clone,
         P: Operator<I>,
         P::Output: Tickable,
     {
-        type Output = TickValue<HashMap<String, <P::Output as Tickable>::Value>>;
+        type Output = TickValue<HashMap<Q, <P::Output as Tickable>::Value>>;
 
         fn next(&mut self, input: I) -> Self::Output {
             let tick = *input.tick();
@@ -72,9 +74,10 @@ mod facet_map {
 
     /// Create an operator that apply different operators to the same input,
     /// and return the collections of outputs as its output.
-    pub fn facet_map_t<I, It, P>(ops: It) -> FacetMap<I, P>
+    pub fn facet_map_t<I, It, Q, P>(ops: It) -> FacetMap<I, Q, P>
     where
-        It: IntoIterator<Item = (String, P)>,
+        Q: Eq + Hash + Clone,
+        It: IntoIterator<Item = (Q, P)>,
     {
         FacetMap(
             ops.into_iter().collect(),
